@@ -437,6 +437,16 @@ expose_event (GtkWidget *widget, GdkEventExpose *event)
     if (GTK_WIDGET_CLASS(tomoe_char_table_parent_class)->expose_event)
         retval = GTK_WIDGET_CLASS(tomoe_char_table_parent_class)->expose_event (widget, event);
  
+    if (GTK_WIDGET_REALIZED (widget) && !priv->pixmap) {
+        priv->pixmap = gdk_pixmap_new(widget->window,
+                                      widget->allocation.width,
+                                      widget->allocation.height,
+                                      -1);
+
+        adjust_adjustments (TOMOE_CHAR_TABLE (widget));
+        tomoe_char_table_draw (TOMOE_CHAR_TABLE (widget));
+    }
+
     if (priv->pixmap)
         gdk_draw_drawable(widget->window,
                           widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
